#
# spec file for package bcachefs-tools
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           bcachefs-tools
Version:        1.3.5
Release:        1.1
Summary:        Configuration utilities for bcachefs
License:        GPL-2.0-or-later
Group:          System/Filesystems
URL:            https://bcachefs.org/

Source:         %name-%version.tar.xz
BuildRequires:  libaio-devel
BuildRequires:  pkg-config
BuildRequires:  xz
BuildRequires:  pkgconfig(blkid)
BuildRequires:  pkgconfig(libkeyutils)
BuildRequires:  pkgconfig(liblz4)
BuildRequires:  pkgconfig(libsodium)
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(liburcu)
BuildRequires:  pkgconfig(libzstd)
BuildRequires:  pkgconfig(uuid)
BuildRequires:  pkgconfig(zlib)

%description
Bcachefs is a filesystem for Linux, with an emphasis on reliability
and robustness.

* Copy on write (COW) - like zfs or btrfs
* Full data and metadata checksumming
* Multiple devices
* Replication
* Erasure coding
* Caching
* Compression
* Encryption
* Snapshots

This package contains utilities for creating and mounting bcachefs.

%prep
%autosetup -p1

%build
%make_build NO_RUST=1 EXTRA_CFLAGS="%optflags"

%install
%make_install PREFIX="%_prefix" ROOT_SBINDIR="%_sbindir" NO_RUST=1
# this ain't no debian
rm -Rf "%buildroot/etc/initramfs-tools" "%buildroot/%_datadir/initramfs-tools"

%files
%_sbindir/*bcache*
%_mandir/man8/*.8*
%license COPYING

%changelog
* Sun Dec  3 2023 Joshua Smith <jsmithfpv@gmail.com>
- Update to v1.3.5:
  * Update from latest kernel bcachefs sources, pulling in fixes
    for deleted_inodes btree in particular
  * cmd_version now works properly
  * fixes for cmd_format, pick the same bucket size for all devices
    for the sake of erasure coding
  * rebalance_work point release
  * Fix race in closure_sync()
  * Updated bcachefs sources because
    bcachefs_metadata_version_deleted_inodes
  * Snapshot depth, skiplist fields
  * Updated bcachefs sources because
    bcachefs_metadata_version_major_minor
  * Fix quotas + snapshots
  * Rip out code for storing backpointers in alloc keys
  * Fragmentation LRU
  * Rework LRU btree
* Tue May 30 2023 Jan Engelhardt <jengelh@inai.de>
- Initial package (version 24) for build.opensuse.org
